<?php

/* ***************************************************************************

  This is main.php, the main page that users will see

  It is an information panel for all users, where they can:
    - see their user information if logged in; log in or register
      if not
    - see some general information about the number of books, number
      of members, etc.
    - see the newest 10 sells
    - see the most popular 10 bids

  If the user is logged in, it becomes more... The user can:
    - see the books he / she is selling, with the highest bid (if no
      one has ever bid for this sell, then the price is red) and:
        - cancel the bid at any time before its ending
        - when selling is over, the user can also:
          - contact the buyer
          - mark the book as "sold"
    - see the books he / she has bid for, with the highest bid and
      if he / she is the current winner of the bid (the price is
      red when the user is loosing, green otherwise); and:
        - bid more, even if he / she is the winner
        - contact the seller when the bid is over

  When called directly, this file will redirect back to the index page

**************************************************************************** */

// PHP should only report big problems
error_reporting(E_ERROR);

// Page has been called, but not by our script !!
if(bath!="university")
{
  header("Location: index.php");
  die();
}

// Number of members

//-- SQL
$query = <<<ENDOFSTRING
SELECT COUNT(*) AS `nb` FROM $usersT
ENDOFSTRING;
//-- ENDSQL

$result_nb_users = $db->query($query);
if( DB::isError($result_nb_users) )
{ 
  echo "Not successful: ".$result_nb_users->getMessage();
  return;
}
else
{
  $result_nb_users = $result_nb_users->fetchRow(DB_FETCHMODE_ORDERED);
   $nb_users = $result_nb_users[0];
}

// Number of online (=logged in) (=with a session ID) users

//-- SQL
$query = <<<ENDOFSTRING
SELECT COUNT(*) AS `nb` FROM $usersT WHERE `Session_id` <> ""
ENDOFSTRING;
//-- ENDSQL

$result_nb_users_connect = $db->query($query);
if( DB::isError($result_nb_users_connect) )
{ 
  echo "Not successful: ".$result_nb_users_connect->getMessage();
  return;
}
else
{
  $result_nb_users_connect = $result_nb_users_connect->fetchRow(DB_FETCHMODE_ORDERED);
   $nb_users_connect = $result_nb_users_connect[0];
}

// Number of books

//-- SQL
$query = <<<ENDOFSTRING
SELECT COUNT(*) AS `nb` FROM $booksT
ENDOFSTRING;
//-- ENDSQL

$result_nb_books = $db->query($query);
if( DB::isError($result_nb_books) )
{ 
  echo "Not successful: ".$result_nb_books->getMessage();
  return;
}
else
{
  $result_nb_books = $result_nb_books->fetchRow(DB_FETCHMODE_ORDERED);
   $nb_books = $result_nb_books[0];
}

// Top 10 for Bids
// Yes, the SQL query may also have used a JOIN ... ON query

//-- SQL
$query = <<<ENDOFSTRING
SELECT $booksT.Title, $bidsT.Sell_id, Bid_price, COUNT(*) AS Nb_bids FROM $bidsT,$sellsT,$booksT
WHERE $bidsT.Sell_id = $sellsT.Sell_id
AND $sellsT.ISBN = $booksT.ISBN
AND $sellsT.Status = 'on sale'
AND $sellsT.`Date_ending` > $t
GROUP BY $bidsT.Sell_id
ORDER BY $bidsT.bid_price
LIMIT 10
ENDOFSTRING;
//-- ENDSQL

$result_top10_bids = $db->query($query);
if( DB::isError($result_top10_bids) )
{ 
  echo "Not successful: ".$result_top10_bids->getMessage();
  return;
}
else
{
  $top10_bids_info = "";
  $nb_top10 = $result_top10_bids->numRows();
  
  if( $nb_top10>0 )
  {  
    $top10_bids_info = "
    <table cellpadding='1' cellspacing='0'> 
      <tr> 
      <td width=130 align=center valign='middle' class='Form_Cadre_title2'><b>Title</b></td>
      <td width=50 align=center valign='middle' class='Form_Cadre_title2'><b>Price</b></td>
      <td width=50 align=center valign='middle' class='Form_Cadre_title2'><b>Action</b></td>
      </tr>";
    
    for( $i=0; $i<$nb_top10; $i++ )
    {
      if( fmod($i,2) == 1 )
        $class = "Form_Cadre_main2";
      else
        $class = "Form_Cadre_main";

      $current = $result_top10_bids->fetchRow(DB_FETCHMODE_ORDERED);
      $top10_bids_info .= "
      <tr>
      <td align='center' valign='middle' class=$class>$current[0]</td>
      <td align='center' valign='middle' class=$class>".($current[2]/10)." </td>
      <td align='center' valign='middle' class=$class><a class=mainPage_link href=index.php?do=bid&sell_id=".$current[1]."$sess_id>Bid</a></td>
      </tr>";
    }
    $top10_bids_info .= "
    </table>";
  }
  else
  {
    $top10_bids_info = "There are no bids !";
  }
}
  
// Newest 10 sells

if($user_id)
{
  $extraConstraint=" AND $sellsT.`BUCS_id` <> \"$user_id\"";
}
else
{
  $extraConstraint="";
}

//-- SQL
$query = <<<ENDOFSTRING
SELECT `Title`, `Sell_id`, `Initial_price` FROM
$booksT JOIN $sellsT ON $booksT.`ISBN` = $sellsT.`ISBN`
AND $sellsT.`Date_ending` > $t
$extraConstraint
ORDER BY `Sell_id` DESC
LIMIT 10;
ENDOFSTRING;
//-- ENDSQL

$result_top10_books = $db->query($query);
if( DB::isError($result_top10_books) )
{ 
  echo "Not successful: ".$result_top10_books->getMessage();
  return;
}
else
{
  $top10_books_info = "";
  $nb_top10 = $result_top10_books->numRows();
  
  if( $nb_top10>0 )
  {  
    $top10_books_info = "
    <table cellpadding='1' cellspacing='0'> 
      <tr> 
      <td width=130 align=center valign='middle' class='Form_Cadre_title2'><b>Title</b></td>
      <td width=50 align=center valign='middle' class='Form_Cadre_title2'><b>Price</b></td>
      <td width=50 align=center valign='middle' class='Form_Cadre_title2'><b>Action</b></td>
      </tr>";
    
    for( $i=0; $i<$nb_top10; $i++ )
    {
      if( fmod($i,2) == 1 )
        $class = "Form_Cadre_main2";
      else
        $class = "Form_Cadre_main";

      $current = $result_top10_books->fetchRow(DB_FETCHMODE_ORDERED);

      // We need a second query to get the current price (including the bids)

//-- SQL
$query = <<<ENDOFSTRING
SELECT `Bid_price` FROM $bidsT WHERE `Sell_id` = $current[1] ORDER BY `Bid_price` DESC LIMIT 1
ENDOFSTRING;
//-- ENDSQL

      $query = $db->query($query);
      if(!DB::isError($query) && ($query->numRows())>0)
      {
        $query=$query->fetchRow(DB_FETCHMODE_ORDERED);
        $current[2]="<span class='green_text'>".($query[0]/10)." </span>";
      }
      else
      {
        $current[2]=($current[2]/10)." ";
      }

      $top10_books_info .= "
      <tr>
      <td align='center' valign='middle' class=$class>$current[0]</td>
      <td align='center' valign='middle' class=$class>$current[2]</td>
      <td align='center' valign='middle' class=$class><a class=mainPage_link href=index.php?do=bid&sell_id=".$current[1]."$sess_id>Bid</a></td>
      </tr>";
    }
    $top10_books_info .= "
    </table>";
  }
  else
  {
    $top10_books_info = "No one is currently selling anything !";
  }
}  

if( !$sess_id )
{
  // User in not logged in...

  $user_info="<br>You need to be logged in to view your user information.<br><br><a class=mainPage_link href=index.php?do=log_in_out>Click here</a> to log in<br><br><a class=mainPage_link href=index.php?do=create_user>Click here</a> to register with the system<br><br>";
  $user_book_bid_info="";
  $your_books="";
} 
else
{
  // User is logged in

  // Check if user has tried to stop selling or mark as sold a book

  $sell_id=intval($_GET['sell_id']);

  if($do=="main" && $sell_id > 0)
  {
    // Yes, it has tried to! Let's find out what we have to do

//-- SQL
$query = <<<ENDOFSTRING
SELECT `Date_ending` FROM $sellsT WHERE `Sell_id` LIKE "$sell_id";
ENDOFSTRING;
//-- ENDSQL

    $query = $db->query($query);
    if(!DB::isError($query) && ($query->numRows())>0)
    {
      $query = $query->fetchRow(DB_FETCHMODE_ORDERED);
      $end_date = intval($query[0]);
      if($end_date > $t)
      {
        // The end date for the bid has not arrived yet, so the book
        // cannot have been sold. The user does not want to sell it
        // anymore, then...

//-- SQL
$query = <<<ENDOFSTRING
UPDATE $sellsT SET `Status` = "removed" WHERE `Sell_id` = $sell_id;
ENDOFSTRING;
//-- ENDSQL

      }
      else
      {
        // The end date for the bid has arrived, and the user could
        // click the "mark as sold" link (remember that if there was
        // no winner the button would have been "sell again", redirecting
        // to some other place... So, the user wants to mark this item
        // as "sold", which normally means that he / she got the money

//-- SQL
$query = <<<ENDOFSTRING
UPDATE $sellsT SET `Status` = "sold" WHERE `Sell_id` = $sell_id;
ENDOFSTRING;
//-- ENDSQL

      }

      $query = $db->query($query);

    }
    else
    {
      // There is a query error (no, there isn't) or an execution error (rare)
      // or the user has entered a non-existing sell_id (possible, yer rare)
      // This should normally (=if the user is just clicking) not be happening
      echo "Unable to find the sell ID you asked for!";
      return;
    }
  }

  // Information about the current user

  // User name, forename, surname, phone number

//-- SQL
$query = <<<ENDOFSTRING
SELECT `BUCS_id`, `Forename`, `Surname`, `Telephone` FROM $usersT WHERE `BUCS_id` LIKE "$user_id";
ENDOFSTRING;
//-- ENDSQL

  $result_user = $db->query($query);
  if( DB::isError($result_user) )
  { 
    echo "Not successful: ".$result_user->getMessage();
    return;
  }
  else
  {
    $result_user = $result_user->fetchRow(DB_FETCHMODE_ORDERED);
    $bucs = $result_user[0];
    $fname = $result_user[1];
    $sname = $result_user[2];
    $tel = $result_user[3];
  }

  $user_info="
  <table width=100%>
    <tr><td width=70 class='Form_Cadre_noborder'><b>BUCS ID</b>:</td><td class='Form_Cadre_noborder'>$bucs</td></tr>
    <tr><td class='Form_Cadre_noborder'><b>Forename</b>:</td><td class='Form_Cadre_noborder'>$fname</td></tr>
    <tr><td class='Form_Cadre_noborder'><b>Surname</b>:</td><td class='Form_Cadre_noborder'>$sname</td></tr>
    <tr><td class='Form_Cadre_noborder'><b>Telephone</b>:</td><td class='Form_Cadre_noborder'>".telephone($tel)."</td></tr>
  </table><br>
  <a class=mainPage_link href=index.php?do=profile$sess_id>Click here</a> to modify your profile<br><br><a class=mainPage_link href=index.php?do=log_in_out$sess_id>Click here</a> to log out";

  // The number of books that user has entered into the system

//-- SQL
$query = <<<ENDOFSTRING
SELECT COUNT(*) AS `nb` FROM $booksT WHERE `BUCS_id` LIKE "$user_id";
ENDOFSTRING;
//-- ENDSQL

  $result_nb_books_user = $db->query($query);
  if( DB::isError($result_nb_books_user) )
  { 
    echo "Not successful: ".$result_nb_books_user->getMessage();
    return;
  }
  else
  {
    $result_nb_books_user = $result_nb_books_user->fetchRow(DB_FETCHMODE_ORDERED);
      $nb_books_user = $result_nb_books_user[0];
  }

  // The books the user is currenly selling

//-- SQL
$query = <<<ENDOFSTRING
SELECT * FROM
$booksT JOIN $sellsT ON $booksT.`ISBN` = $sellsT.`ISBN`
WHERE $sellsT.BUCS_id LIKE "$user_id"
ENDOFSTRING;
//-- ENDSQL

  $result_books_sell = $db->query($query);
  if( DB::isError($result_books_sell) )
  { 
    echo "Not successful: ".$result_books_sell->getMessage();
    return;
  }
  else
  {
    $aff_tabl = "";
    $items=$result_books_sell->numRows();
    if( $items > 0 )
    { 
      $sells = array();
      $prices = array();
      
      for( $i=0; $i<$items; $i++ )
      {
        $current = $result_books_sell->fetchRow(DB_FETCHMODE_ASSOC);

        $sells[$i] = array();
        $query = $current["Sell_id"];
        $sells[$i]["Sell_id"] = $query;
        $sells[$i]["ISBN"] = $current["ISBN"];
        $sells[$i]["Authors"] = $current["Authors"];
        $sells[$i]["Title"] = $current["Title"];
        $sells[$i]["Subject"] = $current["Subject"];
        $end = $current["Date_ending"] - $t;

        // The current price of book

//-- SQL        
$query = <<<ENDOFSTRING
SELECT `Bid_price`, `BUCS_id` FROM $bidsT WHERE `Sell_id` = $query ORDER BY `Bid_price` DESC LIMIT 1
ENDOFSTRING;
//-- ENDSQL

        $query = $db->query($query);

        // We have some tags (<!-- xxx !-->) for a very simple reason: a logicel ordering of items
        // The desired order is:
        //    1) sells that are finished, with a bid winner; yet not delivered (=sold)
        //    2) sells that are not over yet
        //    3) sells that are finished, and no one bought
        //    4) sells that are finished, with a bid winner, and delivered (=marked as sold)
        //    5) sells that that have been cancelled

        if(!DB::isError($query) && ($query->numRows())>0)
        {
          $query = $query->fetchRow(DB_FETCHMODE_ORDERED);
          $buyer = $query[1];
          $prices[$i] = "<!- ".($current["Status"]=="on sale"?($end<1?"a":"b"):"e").$query[0]." -!><span class='green_text'>".($query[0]/10)." </span>";
        }
        else
        {
          $prices[$i] = "<!- ".($current["Status"]=="on sale"?($end<1?"d":"c"):"f").$current["Initial_price"]." -!><span class='red_text'>".($current["Initial_price"]/10)." </span>";
        }

        $action="<a class=mainPage_link href=index.php?do=main&sell_id=".$sells[$i]["Sell_id"]."$sess_id>stop selling</a>";

        if($end<1)
        {

          if($buyer)
          {

            // Sell is finished, and there is a buyer... So we need to grab his / her info

//-- SQL        
$query = <<<ENDOFSTRING
SELECT `Telephone` FROM $usersT WHERE `BUCS_id` = "$buyer";
ENDOFSTRING;
//-- ENDSQL

            $query = $db->query($query);
            if(!DB::isError($query) && ($query->numRows())>0)
            {
              $query = $query->fetchRow(DB_FETCHMODE_ORDERED);
              $end = "Finished: <a class=mainPage_link href=\"mailto:$buyer@bath.ac.uk\" onclick=\"return window.confirm('The buyer\\'s telephone number is ".telephone($query[0])."\\n\\nClick OK to send an e-mail')\">contact buyer</a>";
              if($current["Status"]=="sold")
              {
                $sells[$i]["Action"]="(you've sold this book)";
              }
              else
              {
                $sells[$i]["Action"]="<a class=mainPage_link href=index.php?do=main&sell_id=".$sells[$i]["Sell_id"]."$sess_id>mark as sold</a>";
              }
            }
            else
            {
              // That should never happen
              echo "Error getting buyer information<br><br>";
              return;
            }
          }
          else
          {
            $end = "Finished: no buyers";
            $sells[$i]["Action"]="<a class=mainPage_link href=index.php?do=sell_book&isbn=".$sells[$i]["ISBN"]."$sess_id>sell again</a>";
          }
        }
        else
        {
          if($current["Status"]=="removed")
          {
            $end = "Cancelled";
            $sells[$i]["Action"]="<a class=mainPage_link href=index.php?do=sell_book&isbn=".$sells[$i]["ISBN"]."$sess_id>sell again</a>";
          }
          else
          {
            $sells[$i]["Action"]="<a class=mainPage_link href=index.php?do=main&sell_id=".$sells[$i]["Sell_id"]."$sess_id>stop selling</a>";
            if($end/86400>2)
              $end=intval($end/86400)." days";
            elseif($end/3600>2)
              $end=intval($end/3600)." hours";
            elseif($end/60>5)
              $end=intval($end/60)." minutes";
            else
              $end=intval(intval($end))." seconds";
          }
        }

        $sells[$i]["Time_left"]=$end;

      }
      
      $aff_tabl.= "
      <table width=410 cellpadding='1' cellspacing='0'> 
        <tr> 
        <td width=100 align=center valign='middle' class='Form_Cadre_title2'><b>Author</b></td>
        <td width=100 align=center valign='middle' class='Form_Cadre_title2'><b>Title</b></td>
        <td width=40 align=center valign='middle' class='Form_Cadre_title2'><b>Price</b></td>
        <td width=100 align=center valign='middle' class='Form_Cadre_title2'><b>Time left</b></td>
        <td width=70 align=center valign='middle' class='Form_Cadre_title2'><b>Action</b></td>
        </tr>";
      array_multisort($prices,$sells,SORT_DESC);
      for($i=0;$i<$items;$i++)
      {
        if( fmod($i,2) == 1 )
          $class = "Form_Cadre_main2";
        else
          $class = "Form_Cadre_main";

        $aff_tabl.= "
        <tr>
          <td align=center class=$class>".$sells[$i]["Authors"]."</td>
          <td align=center class=$class>".$sells[$i]["Title"]."</td>
          <td align=center class=$class>".$prices[$i]."</td>
          <td align=center class=$class>".$sells[$i]["Time_left"]."</td>
          <td align=center class=$class>".$sells[$i]["Action"]."</td>
        </tr>";
      }
      
      $aff_tabl.= "</table>";
      $showForm=0;
    }
    else
    {
      $aff_tabl.= "You are not selling any book !<br><br><a class=mainPage_link href=index.php?do=sell_book$sess_id>Click here</a> to start selling a book";
    }
  }

  // Sells the user has bid for

//-- SQL
$query = <<<ENDOFSTRING
SELECT $bidsT.Sell_id, $bidsT.Bid_price, 
       $sellsT.ISBN, $sellsT.Date_ending, $sellsT.Initial_price, $sellsT.BUCS_id, $sellsT.Status,
       $booksT.Title, $booksT.Authors, $booksT.Subject
FROM $bidsT,$sellsT,$booksT
WHERE $bidsT.BUCS_id like "$user_id"
AND $bidsT.Sell_id = $sellsT.Sell_id 
AND $sellsT.ISBN = $booksT.ISBN
AND ($sellsT.Status = "on sale" OR $sellsT.Status = "sold")
ENDOFSTRING;
//-- ENDSQL

  $result_books_bids = $db->query($query);
  if( DB::isError($result_books_bids) )
  { 
    echo "Not successful: ".$result_books_bids->getMessage();
    return;
  }
  else
  {
    $aff_tabl_bids = "";
    $items=$result_books_bids->numRows();
    if( $items > 0 )
    { 
      $sells = array();
      $prices = array();

      for( $i=0; $i<$items; $i++ )
      {
        $current = $result_books_bids->fetchRow(DB_FETCHMODE_ASSOC);

        $sells[$i] = array();
        $query = $current["Sell_id"];
        $sells[$i]["Sell_id"] = $query;
        $sells[$i]["ISBN"] = $current["ISBN"];
        $sells[$i]["Authors"] = $current["Authors"];
        $sells[$i]["Title"] = $current["Title"];
        $sells[$i]["Subject"] = $current["Subject"];
        $end = $current["Date_ending"] - $t;
        $seller = $current["BUCS_id"];

        // Current price information

//-- SQL
$query = <<<ENDOFSTRING
SELECT `Bid_price`, `BUCS_id` FROM $bidsT WHERE `Sell_id` = $query ORDER BY `Bid_price` DESC LIMIT 1
ENDOFSTRING;
//-- ENDSQL

        $query = $db->query($query);
        if(!DB::isError($query) && ($query->numRows())>0)
        {

          // We have some tags (<!-- xxx !-->) for a very simple reason: a logicel ordering of items
          // The desired order is:
          //    1) sells that are finished, where the user has won, and has not bought the item yet
          //    2) sells where the user is currently loosing the bid
          //    3) sells where the user is currently winning the bid
          //    4) sells that are finished, and delivered to the user

          $query = $query->fetchRow(DB_FETCHMODE_ORDERED);
          if( $query[1] == $user_id )
            $prices[$i] = "<!- ".($end<1?($current["Status"]=="sold"?"d":"a"):"c")." -!><span class='green_text'>".($query[0]/10)." </span>";
          else
            $prices[$i] = "<!- b".$query[0]." -!><span class='red_text'>".($query[0]/10)." </span>";
        }
        else
        {
          // This should not happen
          echo "Error getting price information !!";
          return;
        }

        $sells[$i]["Action"] = "<a class=mainPage_link href=index.php?do=bid&sell_id=".$sells[$i]["Sell_id"]."$sess_id>Bid</a>";

        if($end/86400>1)
          $end=intval($end/86400)." days";
        elseif($end/3600>1)
          $end=intval($end/3600)." hours";
        elseif($end/60>5)
          $end=intval($end/60)." minutes";
        elseif($end>0)
          $end=intval(intval($end))." seconds";
        else
        {
          if($query[1] == $user_id)
          {

          // The bid has ended, and the current user is the winner
          // He / she therefore can have access to the buyer's information

//-- SQL        
$query = <<<ENDOFSTRING
SELECT `Telephone` FROM $usersT WHERE `BUCS_id` = "$seller";
ENDOFSTRING;
//-- ENDSQL

            $query = $db->query($query);
            if(!DB::isError($query) && ($query->numRows())>0)
            {
              $query = $query->fetchRow(DB_FETCHMODE_ORDERED);
              $sells[$i]["Action"] = "<a class=mainPage_link href=\"mailto:$seller@bath.ac.uk\" onclick=\"return window.confirm('The seller\\'s telephone number is ".telephone($query[0])."\\n\\nClick OK to send an e-mail')\">contact seller</a>";
            }
            else
            {
              // That should never happen
              echo "Error getting seller information<br><br>";
              return;
            }

            $end=($current["Status"]=="sold"?"Finished, book sold to you":"Winner :)");
          }
          else
          {
            $end = "You've lost :(";
            $sells[$i]["Action"] = "( none )";
          }
        }

        $sells[$i]["Time_left"]=$end;
      }
      
      $aff_tabl_bids.= "
      <table width=410 cellpadding='1' cellspacing='0'> 
        <tr> 
        <td width=100 align=center valign='middle' class='Form_Cadre_title2'><b>Author</b></td>
        <td width=100 align=center valign='middle' class='Form_Cadre_title2'><b>Title</b></td>
        <td width=40 align=center valign='middle' class='Form_Cadre_title2'><b>Price</b></td>
        <td width=100 align=center valign='middle' class='Form_Cadre_title2'><b>Time left</b></td>
        <td width=70 align=center valign='middle' class='Form_Cadre_title2'><b>Action</b></td>
        </tr>";
      array_multisort($prices,$sells,SORT_DESC);
      for($i=0;$i<$items;$i++)
      {
        if( fmod($i,2) == 1 )
          $class = "Form_Cadre_main2";
        else
          $class = "Form_Cadre_main";
        
        $aff_tabl_bids.= "
        <tr>
          <td align=center class=$class>".$sells[$i]["Authors"]."</td>
          <td align=center class=$class>".$sells[$i]["Title"]."</td>
          <td align=center class=$class>".$prices[$i]."</td>
          <td align=center class=$class>".$sells[$i]['Time_left']."</td>
          <td align=center class=$class>".$sells[$i]["Action"]."</td>
        </tr>";
      }
      
      $aff_tabl_bids.= "</table>";
      $showForm=0;
    }
    else
    {
      $aff_tabl_bids.= "You did not bid for any book !<br><br><a class=mainPage_link href=index.php?do=bid$sess_id>Click here</a> to bid for a book";
    }
  }

  $user_book_bid_info="
  <tr>
    <td>
      <table width='100%' cellpadding='1' cellspacing='0' align='center'>
        <tr> 
          <td align='center' valign='middle' class='Form_Cadre_title'> Books that your are selling </td>
        </tr>        
        <tr>
          <td class='Form_Cadre_main' align='center' valign='middle' height='100'><br>
            <div style='width:95%; height:90; overflow:auto'>
            $aff_tabl
            </div>
            <br>
          </td>
        </tr>
      </table>
    </td>
  </tr>
  <tr>
    <td>
      <table width='100%' cellpadding='1' cellspacing='0'>
        <tr> 
          <td align='center' valign='middle' class='Form_Cadre_title'> Books you have bid for </td>
        </tr>        
        <tr>
          <td align=center valign=middle class='Form_Cadre_main' height='100'><br>
            <div style='width:95%; height:90; overflow:auto'>
            $aff_tabl_bids
            </div>
            <br>
          </td>
        </tr>
      </table>
    </td>
  </tr>";

  $your_books="<br>Number of books that your have registered: $nb_books_user";
}

echo "
<table width='100%' cellpadding='1' cellspacing='5'>
  <tr>
    <td valign='top' align='left'>
      <table><tr><td class='box' valign='top'>
      <table width='210' cellpadding='1' cellspacing='5'>
      <tr>
        <td>
          <table width='200' cellpadding='1' cellspacing='0'>
          <tr> 
            <td align='center' valign='middle' class='Form_Cadre_title'> User information </td>
          </tr>        
          <tr>
            <td align=left valign=top class='Form_Cadre_main'>
              <center>$user_info</center>
            </td>
          </tr>
          </table>
        </td>
      </tr>
      </table>
      </td></tr></table>
    </td>
    
    <td width='500' valign='top' align='center'>
      <table width='490'><tr><td class='box' valign='top' align=center>
      <table width='480' cellpadding='1' cellspacing='5'>
        <tr>
        <td>
          <table width='100%' cellpadding='1' cellspacing='0'>
          <tr>
            <td align='center' valign='middle' class='Form_Cadre_title'> General information </td>
          </tr>
          <tr>
            <td align=left valign=top class='Form_Cadre_main'>
              Number of books in the database: $nb_books$your_books<br><br>
              Number of users: $nb_users<br>
              Number of connected users: $nb_users_connect<br>
            </td>
          </tr>
          </table>
        </td>
        </tr>
        $user_book_bid_info
      </table>
      </td></tr></table>
    </td>
    
    <td valign='top' align='right'>
      <table><tr><td class='box' valign='top'>
      <table width='210' cellpadding='1' cellspacing='5'>
        <tr>
        <td>
          <table width='230' cellpadding='1' cellspacing='0'>
          <tr> 
            <td align='center' valign='middle' class='Form_Cadre_title'> Sells: newest 10 </td>
          </tr>        
          <tr>
            <td height='110' align=center valign=top class='Form_Cadre_main'>
            <br>
            <div style='width:220; height:100; overflow:auto'>
              $top10_books_info
            </div>
            <br>
            </td>
          </tr>
          </table>
          <br>
          <table width='230' cellpadding='1' cellspacing='0'>
          <tr> 
            <td align='center' valign='middle' class='Form_Cadre_title'> Bids: top 10 </td>
          </tr>        
          <tr>
            <td height='110' align=center valign=top class='Form_Cadre_main'>
            <br>
            <div style='width:220; height:100; overflow:auto'>
              $top10_bids_info
            </div>
            <br>
            </td>
          </tr>
          </table>
        </td>
        </tr>
      </table>
      </td></tr></table>
    </td>
  </tr>
</table>";

?>
